summaryrefslogtreecommitdiffstats
path: root/src/smsutil.h
diff options
context:
space:
mode:
authorDenis Kenzior <denkenz@gmail.com>2010-09-20 16:21:12 -0500
committerDenis Kenzior <denkenz@gmail.com>2010-09-21 08:44:47 -0500
commite345a6b579f496847ff198cedfa64ef188d0ff8d (patch)
tree607567877fbefb3b256b6905fbdb08f67f861cbe /src/smsutil.h
parent02cca88bcc30f71d5732271f2b8bda9c18f8d3a0 (diff)
downloadofono-e345a6b579f496847ff198cedfa64ef188d0ff8d.tar.bz2
smsutil: update SR assembly to use SHA1 msg ids
Diffstat (limited to 'src/smsutil.h')
-rw-r--r--src/smsutil.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/smsutil.h b/src/smsutil.h
index a81fd6d5..6cf273e9 100644
--- a/src/smsutil.h
+++ b/src/smsutil.h
@@ -20,6 +20,7 @@
*/
#define CBS_MAX_GSM_CHARS 93
+#define SMS_MSGID_LEN 20
enum sms_type {
SMS_TYPE_DELIVER = 0,
@@ -505,10 +506,10 @@ struct status_report_assembly *status_report_assembly_new(const char *imsi);
void status_report_assembly_free(struct status_report_assembly *assembly);
gboolean status_report_assembly_report(struct status_report_assembly *assembly,
const struct sms *status_report,
- unsigned int *msg_id,
+ unsigned char *out_msgid,
gboolean *msg_delivered);
void status_report_assembly_add_fragment(struct status_report_assembly
*assembly, unsigned int msg_id,
const struct sms_address *to,
unsigned char mr, time_t expiration,
unsigned char total_mrs);
@@ -505,10 +506,10 @@ struct status_report_assembly *status_report_assembly_new(const char *imsi);
gboolean *msg_delivered);
void status_report_assembly_add_fragment(struct status_report_assembly
- *assembly, unsigned int msg_id,
+ *assembly, const unsigned char *msgid,
const struct sms_address *to,
unsigned char mr, time_t expiration,